==> win32_Release_v3.2.6_r375.zip: data/scripts/ui/chat/Global.lua <==
amtaLx  VFw|S<N>Q#B6_0^p7[4V7[peExX#^T^gϛӺ΋Ҽչ114gvu|.(Ƨκ"+llW·ïƢssp?Q=T:_xGGNff`D6D%\S@tqt7Y<%bca47U^4߭ȩZD1_<PnfNgmdge	)L糰ڎΡϻް;c
yǫᙘرݸ	wu|Z=  UH'H$Wyے&vۘպԋ̯GJpTRZi_oObBzZqQc
&3"/7!EBAmn4޹ܨ	95]]qе P0!Ŭtf&LH*M.&;橬!G(陘ԵײšũɩϠνɻڳSdmckE=0!=)kypyުf40:ˉ񴓺VVVU{`nx,U%@nq?^3VzZ='+03""W]
ykdJ)D og+N(\z`w[ϝ
	D_;cS{B]m$#8: a`HߘޱYm*(A3R+ܰֲӿ۾@R`MF2 WX]sW@ͣǢƯگۯޮڣolDfkGм\Y;.M"N>Χ^wLN}EuYy56aAlL{Ffk)5M(P^vݥl3@AlDFV{	ԧ<9h@bܹ▘02߉̞RCiL@vceObbP(2RaPbwҎ 48dnG4T^].B+O*X8ᓼ8<블  !/<ᵣ2tEb#$?#(..16&wuy[)98;K$T!Q+Ϲܮ/376;ICdoHaO6&7  JLeoFzUHT|^1;W+8˩'?__;5# ᝖D@쌤A`UuqUQ럺jgeBiϭwSkAo~=*Q-~5IҐדQ^UXUE=Ƣ**
#ma20"&/ **ĸŬȠ&#cI#
.&'S:W2h5%'/\9Mrh
f+}rR%D6X1_hٺ zG]:_	lwx8tL$䡁us`򝺪gmmdG-,B#Nl<
usl".2ը<?-/&
"_^#_llmd6]q'N  ixc8Qī1Ef	!˪ΧtPV	+%+_0CgcNB4s>2}vo
yIgWcI);ܳ4!".(`5Pz]>?=Q=H-67Bj̯keĭʢڢ %V'+\
a
7-xRNl1	9,̼w@"NRⰴǶ<SdBߖݑю:-3sq
׻FW^}Aq>׫z|WOYHo/=!7k$ 훵ѪJW!ãipyT>0֞swmALGrnkO;eȇ犢@5Y_xPXn*RJ8N'S;zzB@0GcQ[f|# N)[>[yԓgptFuCoOxLrX"   &u`q8V0_xPC}u[VDJKgGbӪ^OStV~&,{Y:p"e'{y]p]}~l9V_w(*
]Zn,hJ/ČvY%8
ҙbJxHqZABC~
f@>=0<$ka~
bo
}oWЦ^{qT={z2[5AcKdFw!b@i>Qs3'׾t=꼰и٭¬Ȥݳ
EײѴݫΪ_VΠΫȼٽ{pPR0Z
-
-
d"L#WwM$W'34f	fJ<]4X9om0B鉁=p//jggǴݤRS:IkīԆ6ppӮwtP؜LbB\P6piY)Nz̒%I'޲9Ʋ" TX0㟵IefoyvQyq/'$f`1sho)@,@b*I4?5\YyyZFAc ( 4:8L>K.$PoTȣġҦԻ8V0X_t<\
/<N+F)_:{{S78.G!;9%(h=MCd{pKuu]eddDKOMWhs.QqAjri;&ҦqdCǖllD_;:,D<^frg )Jb>?[^\?W2Q:ӛױæսbɧⶰ1z|lEf>jP*0<FfFOHAf[U{򚑶.FPsC4%m9%?\El8?텯UcjciR&3l/Ը98K#L;pzgaG{ׅҠϠУ'.FRR651vV>Q&LH,^zIV־׳F`ct uit}XLb_gԵ=fҼչ4:ge0C&T?*JM2ţܨɻƣϿڨى\j|#.">"NAb]^e5T HdmC뙻8."݂㌎u!1Qed4dbFʵt{t0\YϟԸ55ߋSy[+:LLlQtPw33JJHf>#
HHc㛻׷¤±Ԡ++	_CútWtsxVǢjkI1DlqXi[W&NrpK_w9t~]!)1XxI!*VcRn`8s00rMsT Ŷ錮;62
y
b-缞ٽzRv녾nnlEe[{Kh5{TiUڻɬ]wu;&JK;Ƨ]oŽ4HO<r|~Ng/v؄Ʃǳ A-D'LdT8MGgzFDf$㓗ܻպ̡ጬw~t}HjNvVWwܕ ^?,zQ2>Ǣ^RV;􀊃ɨϪЅǮTr{3f"`tVzZ}_7P5_٭=>97zXzH|V?YY{(1 ZX(˭ˮ'T$!Ƒ6fE1FFGf
sㆢz2!%0 ~p^_^l@W'ѿ޹ܮ4yUwǸMO|[m;B_]{W{9ԽΪۯضӿj\􈍯) ,GEqVEGPg$9;4?>MF#Pq5\=Q>oMm	lE(IFMXN	GZ@MH
_{{=;CKlޱîϻ޺`꺘|X,!Ĺ,=e{Q8qAmp/Ϸڿѵx"˖Hs(\^ߖȪVX;Kh Cj%^]<X<;3;:A'6ԬXY4wpi&$ipY|X{=IbfqSn-X*qV~\:<n)o
qSf_;@Ȼڬ	LozzY	NFG{BeԠ법ͭ>4{{S~G~RruwtSsihbhbr[?@2818ZTto5=T&1ajI
6<5fJB@䋺XV?YᭀleWV!*!+'
ϫĳT$ttv[{J@Jxhd࿝,9FMLZPp}~ķâФѿ%(s׸kؽw^qǆ.*RWf3`QR Y{Ka9E$$&yfm
K(ؓHyȥ5;y[WmCaaGwF`Y择yEm=B ļV78ܲRla6qu]tNGFfg?OD4mOwI%%/ڢw٬呕̉ߚԀߊÇ؋ߞ̘ǂƏ'P	tMc↖Vs#
-%ŀԁӝօonMQrsp61x+cCKå̢˸;:鴲Տ54,ee^6jWsI!hBݺe.ش2g|8ퟞ悡$	%0Mkg8+rpVcAMpJ
.McAm,X}eֵ<2(=Ā*GeZ21n7
}}Xх#&>X7LeBm2_,K#(
bϪvu]pɥ$&uW'D ɷZ'fRpн+
&z쯝
O D,/圾Zf9~} xιmIoǐ|eGwJ$	8XI"^QvDfMOHpt
6N&!/Gv:DqF.^40^5dm/*^2jm::VZ7ڞ&A$P{燎ȡt"ϐ>&rxVD~q_CI^jcwS3 +[Pwt9$aHuY[v OꂧOpK¶6"-qRo0O'5谶~q*1JB;K.@gH$ #p	zkj GЈ(БϬ,.E~qQff
)k
d
oI0Bz	.vaDЂä<=T{ )&N/Ab6a`	z8Y{c<PVt>}xV4U;dbf=Vs{?RcW*.9
2:Tw!էMj4lKGDvL;;0<li8cCF1%T̰m>FGoKꗖ'NY{m\%	)/4۵їs?O/!!	<%i]{C*(	Da	6<02jA(,`It:b@S~=ȥѴѵ NRP~quSn=yW;6-7>RT{XYO
[v[y}==ptE%][ylPpK#63::e\謮o=}"11 &%dCOzX<Twf	4l%hL:%iɦԤ-B+
=j-=m9HrJW\~`D.vU3r=MĭtZ"3[~\d_8]vGe#%̿瓱}=cӏmn#L:_
z]e6z_]4GaV$3
#wzȭ^gag=EGgiMLoi:0} dm
暛:8oH>V$)7]ܮ}HN;%<ªsRyTbc %
#]548ueb֮tS倢󗷿3EDc@KI;rRo}yIaNMaApRA"0]Sxtv.hJl8v|u ibx]78O}tSgg61
#%:<ܽlAp(У{񣇫1  3CIVy?oBP"^vՉrQJjK{B&/S&.UL߳eIH\1tsQ7HZx!I^W}QPvYXzK%-PCm2OBa٭C;`@e`I/#7r{WSP5ɬG@n;ɠ4X_g˛䐰̀&9qYsČegzJzoEm8|_p 0"9+<jiDedձ@F}r_BbH@Ak2F3}FeA̘\enKkZڻIi{4L>"dUmlؤZ3F|U1; ղMAdӧQꪄ兰c^~lKrr,8m*R9[#Y{ō5?g|}qf
yP4 ٽ#hgT`TG\JV蓺~6%}Y1?+#
;+)`oM3OBIY{]Χ`(,BDj 5j-T83RWúƩEڦw1XoFeuHdǮ݄랼tT9䷛ =ϮɟQy[緟KP@Bv"0PYIHher
*:;ErxgƾtVNM"lh߳Quv4U'5Z55\:tsN,:8]%Q|QC?08A.[r`Pİ`CĪy۸+1zyuqVH\011]X,An3KiK#B$%+8dhx|0	bthdF⢣-e
i)#GB&%T%vX|H˳eK뢋-6BL`
+|a+ӿΐhQ>2Q,w
fhMm)CEg`ㆢ~ykb/N6sf M,Tvkk.B62,^|RzBD]` pxkK٘ꖭJ^w
5EB`؎Ư§Lz{[v[{oJRJ"&[t,lܢA-SVjoŊ"r:n`wm}~cM13dtkxTg
vđ ff(቏ɥ M@hA&R{Pbྌ&4:?*yNj_仞.ȧ"cBhDDh7R^dtvRik%@!S6%s`qb
dF==tUչxftgeExXhF)Ǯ\!``Rwg'D0ᄼC(Ri7Rxp6"8@>703j~sWʮjJY& &"7CUd4@O˵Łx|bpS,G?=Y^:b32:09+UW{qx 	/ 2!ZyZk8  eg	l-;
(!C@m-,ccG7ɸhɖeM.
wt $ }t]Q%Zzy]\w8m|nb͏]\S71tt^6?103|O؜"
^5;%ˊܽ5hCsr
1]`jC,<UBpR坔l6*8<03#&㿸 &#+-ݹGNnm8 cpc7,<&<u`4L=-)--l[Sn9}	84=-=0/->҉h+;G}wF+<UU}%Y]@ddfBڞ޷=˿!럠LHmе?7m9nEginCae5ᕯOIfm]kj.hO##p^p3. iGiecAY
r5rZ~oZrpMxTqeVVZScz]75b@<OlJY**^zJOvbsS!.- Ș熇~|Mc0aO\/ ߵy[ꚸ#ә.(S1&LlթkbٕwyDHD	`$SB#&O<~
d I:(l
(Xp 5=8cR&i;ݧ>"29q*)&&,@EhyzEÃimD-		ɤަ3Wz$<mo@TS:JF}EeI	 )腌SRj`i dFbBqY\g[ITYyz|#nIǧ֏?<X8MX5~U23ΰ7'epACc^~Sb===
ΚxoAV.\(ikCkJjxz{57ꎢ񔽷Ҽ

==> win32_Release_v4.0.2_r972.zip: data/scripts/ui/chat/Global.lua <==
amta{  VFw|S<N>Q#B6_0^p7[4V7[peExX#^T^gϛӺ΋Ҽչ114gvu|.(Ƨκ"+llW·ïƢssp?Q=T:_xGGNff`D6D%\S@tqt7Y<%bca47U^4߭ȩZD1_<PnfNgmdge	)L糰ڎΡϻް;c
yǫᙘرݸ	wu|Z=  UH'H$Wyے&vۘպԋ̯GJpTRZi_oObBzZqQc
&3"/7!EBAmn4޹ܨ	95]]qе P0!Ŭtf&LH*M.&;橬!G(陘ԵײšũɩϠνɻڳSdmckE=0!=)kypyުf40:ˉ񴓺VVVU{`nx,U%@nq?^3VzZ='+03""W]
ykdJ)D og+N(\z`w[ϝ
	D_;cS{B]m$#8: a`HߘޱYm*(A3R+ܰֲӿ۾@R`MF2 WX]sW@ͣǢƯگۯޮڣolDfkGм\Y;.M"N>Χ^wLN}EuYy56aAlL{Ffk)5M(P^vݥl3@AlDFV{	ԧ<9h@bܹ▘02߉̞RCiL@vceObbP(2RaPbwҎ 48dnG4T^].B+O*X8ᓼ8<블  !/<ᵣ2tEb#$?#(..16&wuy[)98;K$T!Q+Ϲܮ/376;ICdoHaO6&7  JLeoFzUHT|^1;W+8˩'?__;5# ᝖D@쌤A`UuqUQ럺jgeBiϭwSkAo~=*Q-~5IҐדQ^UXUE=Ƣ**
#ma20"&/ **ĸŬȠ&#cI#
.&'S:W2h5%'/\9Mrh
f+}rR%D6X1_hٺ zG]:_	lwx8tL$䡁us`򝺪gmmdG-,B#Nl<
usl".2ը<?-/&
"_^#_llmd6]q'N  ixc8Qī1Ef	!˪ΧtPV	+%+_0CgcNB4s>2}vo
yIgWcI);ܳ4!".(`5Pz]>?=Q=H-67Bj̯keĭʢڢ %V'+\
a
7-xRNl1	9,̼w@"NRⰴǶ<SdBߖݑю:-3sq
׻FW^}Aq>׫z|WOYHo/=!7k$ 훵ѪJW!ãipyT>0֞swmALGrnkO;eȇ犢@5Y_xPXn*RJ8N'S;zzB@0GcQ[f|# N)[>[yԓgptFuCoOxLrX"   &u`q8V0_xPC}u[VDJKgGbӪ^OStV~&,{Y:p"e'{y]p]}~l9V_w(*
]Zn,hJ/ČvY%8
ҙbJxHqZABC~
f@>=0<$ka~
bo
}oWЦ^{qT={z2[5AcKdFw!b@i>Qs3'׾t=꼰и٭¬Ȥݳ
EײѴݫΪ_VΠΫȼٽ{pPR0Z
-
-
d"L#WwM$W'34f	fJ<]4X9om0B鉁=p//jggǴݤRS:IkīԆ6ppӮwtP؜LbB\P6piY)Nz̒%I'޲9Ʋ" TX0㟵IefoyvQyq/'$f`1sho)@,@b*I4?5\YyyZFAc ( 4:8L>K.$PoTȣġҦԻ8V0X_t<\
/<N+F)_:{{S78.G!;9%(h=MCd{pKuu]eddDKOMWhs.QqAjri;&ҦqdCǖllD_;:,D<^frg )Jb>?[^\?W2Q:ӛױæսbɧⶰ1z|lEf>jP*0<FfFOHAf[U{򚑶.FPsC4%m9%?\El8?텯UcjciR&3l/Ը98K#L;pzgaG{ׅҠϠУ'.FRR651vV>Q&LH,^zIV־׳F`ct uit}XLb_gԵ=fҼչ4:ge0C&T?*JM2ţܨɻƣϿڨى\j|#.">"NAb]^e5T HdmC뙻8."݂㌎u!1Qed4dbFʵt{t0\YϟԸ55ߋSy[+:LLlQtPw33JJHf>#
HHc㛻׷¤±Ԡ++	_CútWtsxVǢjkI1DlqXi[W&NrpK_w9t~]!)1XxI!*VcRn`8s00rMsT Ŷ錮;62
y
b-缞ٽzRv녾nnlEe[{Kh5{TiUڻɬ]wu;&JK;Ƨ]oŽ4HO<r|~Ng/v؄Ʃǳ A-D'LdT8MGgzFDf$㓗ܻպ̡ጬw~t}HjNvVWwܕ ^?,zQ2>Ǣ^RV;􀊃ɨϪЅǮTr{3f"`tVzZ}_7P5_٭=>97zXzH|V?YY{(1 ZX(˭ˮ'T$!Ƒ6fE1FFGf
sㆢz2!%0 ~p^_^l@W'ѿ޹ܮ4yUwǸMO|[m;B_]{W{9ԽΪۯضӿj\􈍯) ,GEqVEGPg$9;4?>MF#Pq5\=Q>oMm	lE(IFMXN	GZ@MH
_{{=;CKlޱîϻ޺`꺘|X,!Ĺ,=e{Q8qAmp/Ϸڿѵx"˖Hs(\^ߖȪVX;Kh Cj%^]<X<;3;:A'6ԬXY4wpi&$ipY|X{=IbfqSn-X*qV~\:<n)o
qSf_;@Ȼڬ	LozzY	NFG{BeԠ법ͭ>4{{S~G~RruwtSsihbhbr[?@2818ZTto5=T&1ajI
6<5fJB@䋺XV?YᭀleWV!*!+'
ϫĳT$ttv[{J@Jxhd࿝,9FMLZPp}~ķâФѿ%(s׸kؽw^qǆ.*RWf3`QR Y{Ka9E$$&yfm
K(ؓHyȥ5;y[WmCaaGwF`Y择yEm=B ļV78ܲRla6qu]tNGFfg?OD4mOwI%%/ڢw٬呕̉ߚԀߊÇ؋ߞ̘ǂƏ'P	tMc↖Vs#
-%ŀԁӝօonMQrsp61x+cCKå̢˸;:鴲Տ54,ee^6jWsI!hBݺe.ش2g|8ퟞ悡$	%0Mkg8+rpVcAMpJ
.McAm,X}eֵ<2(=Ā*GeZ21n7
}}Xх#&>X7LeBm2_,K#(
bϪvu]pɥ$&uW'D ɷZ'fRpн+
&z쯝
O D,/圾Zf9~} xιmIoǐ|eGwJ$	8XI"^QvDfMOHpt
6N&!/Gv:DqF.^40^5dm/*^2jm::VZ7ڞ&A$P{燎ȡt"ϐ>&rxVD~q_CI^jcwS3 +[Pwt9$aHuY[v OꂧOpK¶6"-qRo0O'5谶~q*1JB;K.@gH$ #p	zkj GЈ(БϬ,.E~qQff
)k
d
oI0Bz	.vaDЂä<=T{ )&N/Ab6a`	z8Y{c<PVt>}xV4U;dbf=Vs{?RcW*.9
2:Tw!էMj4lKGDvL;;0<li8cCF1%T̰m>FGoKꗖ'NY{m\%	)/4۵їs?O/!!	<%i]{C*(	Da	6<02jA(,`It:b@S~=ȥѴѵ NRP~quSn=yW;6-7>RT{XYO
[v[y}==ptE%][ylPpK#63::e\謮o=}"11 &%dCOzX<Twf	4l%hL:%iɦԤ-B+
=j-=m9HrJW\~`D.vU3r=MĭtZ"3[~\d_8]vGe#%̿瓱}=cӏmn#L:_
z]e6z_]4GaV$3
#wzȭ^gag=EGgiMLoi:0} dm
暛:8oH>V$)7]ܮ}HN;%<ªsRyTbc %
#]548ueb֮tS倢󗷿3EDc@KI;rRo}yIaNMaApRA"0]Sxtv.hJl8v|u ibx]78O}tSgg61
#%:<ܽlAp(У{񣇫1  3CIVy?oBP"^vՉrQJjK{B&/S&.UL߳eIH\1tsQ7HZx!I^W}QPvYXzK%-PCm2OBa٭C;`@e`I/#7r{WSP5ɬG@n;ɠ4X_g˛䐰̀&9qYsČegzJzoEm8|_p 0"9+<jiDedձ@F}r_BbH@Ak2F3}FeA̘\enKkZڻIi{4L>"dUmlؤZ3F|U1; ղMAdӧQꪄ兰c^~lKrr,8m*R9[#Y{ō5?g|}qf
yP4 ٽ#hgT`TG\JV蓺~6%}Y1?+#
;+)`oM3OBIY{]Χ`(,BDj 5j-T83RWúƩEڦw1XoFeuHdǮ݄랼tT9䷛ ĸ74lLqQgWr*#Rުˬ`Hjb3;'75_VFG+&1	TxhiOv|rӫZAm!73ݡ!k}B:B a0eرCoHH-¢r8w{V{i߰"(\XI(F-eK(;k7
khd`GgF@0}|٥Gjc<?ަs6	%0!6pFSvaƲ{vT@ T5Rz˫ՔLB`NhHxQ$j镂Fi͇&)
djF2Z(G*
&R^.4%/IxN\Kq
iۿř䈆3Uwo"Z3^;SI,X,I;DM a1\=I!b{Yn|d.ҁxzR{[vVd|-qҖ3$3_
	1saO;3 &dNbbNjQ~FSzʲ=I.π3#gR-=7ʺ7;)ARk}k^w"'ͼZvn?O_tѕ$C` kYtgun d
~ʝEب18/qͮ-nGSAW]3Tv:͢҂쉮9k~VJKN:U;N#A$Vq̬|aZ榑T}ǳFUG6SW1EBk#Cl7;SW/(89e<0ܱ7OF24\񐣋n|_pw%QS?v("A5= ELu\v
'𹁔[ @SU
y
R1D4k_v^_x,Ň/ԸٺiCV4Թ,tg@Yia_s}|N{qx^EEeNZ!U{@@(jqc7 6ƀ܃=?`}
(F֑CFl@@c?fO*&5ސ惐bB6S@D8z<JStG&4HJjWwGiKTpPt)(-
?N1ũs<(P-, ֺuM$cFޒ
>4)/3u_<,&/?=Eq% 	["7Ǔ?43.oKDaAR`cKkiA}Tw12hg
}9J{sUlDmWr~֮ϫ7q281L+
|uS`ol	eqQ}wgq}?^}`ލ,6
83<4|hT_ƨͩeL}*+PQ 	#$T#봐`0/Ccjج`WٵHMmnbcDfeEh]QTU}MMpfJjBm8;<䀆JJ`-]a2⦧EWGLp:ՙ٘|N1ac!4ɱkK@X]@S~^MkCtM$3#Ʋˎ2hJfhQRBG508>ΪT]}~+3Cr%"bJZ@iǿڢHH	
8HWCCBoO+_nbkK{kfƟ䤊~|o玳Jz,&zHm1Wj>" (@<м8%7'ςꗷDCaт\*ȽxpUd  o_sSbŵ7
ĸAqGF(Dc4з2*:8QԏsuW`@A 0'><<#;-
5- 	#<}4'w;BeJwkIq]*$XcCNLHd45UoOXDfK*+{yHf5dJi
FfFzZ	3;: m}~雸,H蘺>Q~:,PzJKobO~^盾YP}F7#nVlطoiD!ݳlNwDk'&췆ҽ(u	sW?>jzw(x;11z1AQ[sb]/s@ieWdGGȬ}4RIj&ok_奬}nD) I[KVyھllf@ܣy"\rKYL\YsֿSt)*N.[N#_@?@GoӈtdTU&G3FRz+S'4fMt*
K}P  R`CIe!@CI-!U'R7q{q```
